@@ -1,26 +1,31 @@
 """Runway config file module."""
 # pylint: disable=super-init-not-called,too-many-lines
-from typing import (Any, Dict, List, Optional,  # pylint: disable=unused-import
-                    Union, Iterator, TYPE_CHECKING)
-
-# python2 supported pylint is unable to load this when in a venv
-from distutils.util import strtobool  # pylint: disable=no-name-in-module,import-error
 import logging
 import os
 import sys
+# python2 supported pylint is unable to load this when in a venv
+from distutils.util import strtobool  # pylint: disable=E
+from typing import (TYPE_CHECKING, Any, Dict,  # pylint: disable=unused-import
+                    Iterator, List, Optional, Union)
 
-from six import string_types
 import yaml
+from six import string_types
 
+from ._logging import PrefixAdaptor
 from .util import MutableMap, cached_property
 from .variables import Variable
 
+if sys.version_info.major > 2:
+    from pathlib import Path  # pylint: disable=E
+else:
+    from pathlib2 import Path  # pylint: disable=E
+
 # python2 supported pylint sees this is cyclic even though its only for type checking
 # pylint: disable=cyclic-import
 if TYPE_CHECKING:
     from .context import Context  # noqa: F401 pylint: disable=unused-import
 
-LOGGER = logging.getLogger('runway')
+LOGGER = logging.getLogger(__name__)
 NoneType = type(None)
 
 
@@ -107,14 +112,22 @@ class ConfigComponent(MutableMap):
                 populated until processing has begun.
 
         """
+        logger = PrefixAdaptor(self.name, LOGGER) \
+            if hasattr(self, 'name') else LOGGER
+        if pre_process:
+            logger.verbose('resolving variables for pre-processing...')
+        else:
+            logger.verbose('resolving variables...')
         for attr in (self.PRE_PROCESS_VARIABLES if pre_process
                      else self.SUPPORTS_VARIABLES):
-            LOGGER.debug('Resolving %s.%s', self.name, attr)
+            logger.debug('resolving %s...', attr)
             getattr(self, '_' + attr).resolve(context, variables=variables)
 
     def __getitem__(self, key):
         # type: (str) -> Any
         """Implement evaluation of self[key]."""
+        if not isinstance(key, string_types):
+            raise TypeError('indices must be a string')
         result = getattr(self, key, getattr(self, key.replace('-', '_')))
 
         if isinstance(result, Variable):
@@ -362,6 +375,15 @@ class ModuleDefinition(ConfigComponent):  # pylint: disable=too-many-instance-at
         raise ValueError('{}.class_path = {} is of type {}; expected type '
                          'of str'.format(self.name, value, type(value)))
 
+    @property
+    def menu_entry(self):
+        """Return menu entry representation of this module."""
+        if self.child_modules:
+            return '{name} [{children}]'.format(
+                name=self.name,
+                children=', '.join([c.menu_entry for c in self.child_modules]))
+        return self.name
+
     @property
     def options(self):
         # type: () -> Dict[Any, Any]
@@ -769,6 +791,15 @@ class DeploymentDefinition(ConfigComponent):  # pylint: disable=too-many-instanc
         raise ValueError('{}.assume_role is of type {}; expected type '
                          'of dict or str'.format(self.name, type(value)))
 
+    @property
+    def menu_entry(self):
+        """Return menu entry representation of this deployment."""
+        return '{name} - {modules} ({regions})'.format(
+            name=self.name,
+            modules=', '.join([module.name for module in self.modules]),
+            regions=', '.join(self.regions or self.parallel_regions)
+        )
+
     @property
     def module_options(self):
         # type: () -> Dict[Any, Any]
@@ -1026,10 +1057,14 @@ class VariablesDefinition(MutableMap):
                             'must of be of type str but got types {} and {}'.format(
                                 type(file_path), type(sys_path)))
         if not sys_path:
+            LOGGER.debug('sys_path not provided; using current working '
+                         'direcotry')
             sys_path = os.getcwd()
 
         if file_path:
             result = os.path.join(sys_path, file_path)
+            LOGGER.verbose('using explicit variables file: %s',
+                           result)
             if os.path.isfile(result):
                 return result
             LOGGER.error('The provided variables "%s" file could not '
@@ -1038,7 +1073,9 @@ class VariablesDefinition(MutableMap):
 
         for name in cls.default_names:
             result = os.path.join(sys_path, name)
+            LOGGER.debug('looking for variables file: %s', result)
             if os.path.isfile(result):
+                LOGGER.verbose('found variables file: %s', result)
                 return result
 
         LOGGER.info('Could not find %s in the current directory. '
@@ -1067,13 +1104,17 @@ class VariablesDefinition(MutableMap):
     def _load_from_file(cls, file_path):
         # type: (str) -> VariablesDefinition
         """Load the variables file into an object."""
+        LOGGER.debug('attempting to load variables files: %s',
+                     file_path)
         if not os.path.isfile(file_path):
             LOGGER.error('The provided variables "%s" file could not '
                          'be found.', file_path)
             sys.exit(1)
 
         with open(file_path) as data_file:
-            return cls(**yaml.safe_load(data_file))
+            result = cls(**yaml.safe_load(data_file))
+            LOGGER.debug('variables file loaded')
+            return result
 
 
 class Config(ConfigComponent):
@@ -1170,41 +1211,53 @@ class Config(ConfigComponent):
 
     @classmethod
     def load_from_file(cls, config_path):
-        # type: (str) -> Config
+        # type: (Path) -> Config
         """Load config file into a Config object."""
-        if not os.path.isfile(config_path):
+        if not isinstance(config_path, Path):  # legacy support
+            config_path = Path(config_path)
+        if not config_path.is_file():
             LOGGER.error("Runway config file was not found (looking for "
                          "%s)",
                          config_path)
             sys.exit(1)
-        with open(config_path) as data_file:
-            config_file = yaml.safe_load(data_file)
-            result = Config(config_file.pop('deployments'),
-                            config_file.pop('future', {}),
-                            config_file.pop('tests', []),
-                            config_file.pop('ignore_git_branch',
-                                            config_file.pop(
-                                                'ignore-git-branch',
-                                                False)),
-                            config_file.pop('variables', {}))
 
-            if config_file:
-                LOGGER.warning(
-                    'Invalid keys found in runway file have been ignored: %s',
-                    ', '.join(config_file.keys())
-                )
-            return result
+        LOGGER.debug('attempting to load config: %s', config_path)
+        config_file = yaml.safe_load(config_path.read_text()) or {}
+        result = Config(config_file.pop('deployments'),
+                        config_file.pop('future', {}),
+                        config_file.pop('tests', []),
+                        config_file.pop('ignore_git_branch',
+                                        config_file.pop(
+                                            'ignore-git-branch',
+                                            False)),
+                        config_file.pop('variables', {}))
+
+        if config_file:
+            LOGGER.warning(
+                'Invalid keys found in runway file have been ignored: %s',
+                ', '.join(config_file.keys())
+            )
+        LOGGER.debug('config loaded')
+        return result
 
     @classmethod
     def find_config_file(cls, config_dir=None):
-        # type: (Optional[str]) -> str
+        # type: (Optional[Path]) -> Path
         """Find the Runway config file."""
+        if not isinstance(config_dir, Path):  # legacy support
+            config_dir = Path(config_dir)
         if not config_dir:
-            config_dir = os.getcwd()
+            LOGGER.debug('config_dir not provided; using current '
+                         'working directory')
+            config_dir = Path.cwd()
+        elif not isinstance(config_dir, Path):  # legacy support
+            config_dir = Path(config_dir)
 
         for name in cls.accepted_names:
-            conf_path = os.path.join(config_dir, name)
-            if os.path.isfile(conf_path):
+            conf_path = config_dir / name
+            LOGGER.debug('looking for variables file: %s', conf_path)
+            if conf_path.is_file():
+                LOGGER.verbose('found config: %s', conf_path)
                 return conf_path
 
         LOGGER.error('Runway config file was not found. Looking for one '
